<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.Pwm.Provider

Windows Runtime (WinRT) APIs for for the `Windows.Devices.Pwm.Provider` namespace.

This package provides the `winrt.windows.devices.pwm.provider` module.
